diff -Nur c860_040114/linux/drivers/char/ads7846_ts.c c860_040124/linux/drivers/char/ads7846_ts.c
--- c860_040114/linux/drivers/char/ads7846_ts.c	2004-11-08 18:34:35.000000000 +0900
+++ c860_040124/linux/drivers/char/ads7846_ts.c	2004-11-08 18:34:58.000000000 +0900
@@ -86,9 +86,12 @@
 static int head, tail, sample;
 static char pendown = 0;
 static unsigned long Pressure;
+#if defined(CONFIG_SL_TS_PRESSURE) || defined(CONFIG_SL7X0_POWER_KEY_OFF) || defined(CONFIG_SL_3BUTTON_PATCH)
+#include <linux/proc_fs.h>
+#endif
+
 #if defined(CONFIG_SL_TS_PRESSURE)
 static unsigned long tsPressure;
-#include <linux/proc_fs.h>
 static unsigned int tspressure_mode = 0;
 
 static ssize_t tspressure_read_params(struct file *file, char *buf,
@@ -139,8 +142,85 @@
  #endif // CONFIG_PM
 #endif
 
+#if defined(CONFIG_SL7X0_POWER_KEY_OFF)
+extern unsigned int power_key_off_mode;
+
+static ssize_t power_key_off_read_params(struct file *file, char *buf,
+				      size_t nbytes, loff_t *ppos)
+{
+	char outputbuf[32];
+	int count;
+
+	if (*ppos>0) /* Assume reading completed in previous read*/
+		return 0;
+	count = sprintf(outputbuf, "%d\n", (unsigned int)power_key_off_mode);
+	count++;
+	*ppos += count;
+	if (count>nbytes)	/* Assume output can be read at one time */
+		return -EINVAL;
+	if (copy_to_user(buf, outputbuf, count+1))
+		return -EFAULT;
+	return count;
+}
+
+static ssize_t power_key_off_write_params(struct file *file, const char *buf,
+				       size_t nbytes, loff_t *ppos)
+{
+	unsigned int param=0;
+
+	sscanf(buf,"%d",&param);
+	if (power_key_off_mode != param) {
+		power_key_off_mode = param;
+		printk("power_key_off = %d\n", power_key_off_mode);
+	}
+	return nbytes;
+}
+
+static struct file_operations proc_power_key_off_operations = {
+  read:   power_key_off_read_params,
+  write:  power_key_off_write_params,
+};
+#endif
+
 #if defined(CONFIG_SL_3BUTTON_PATCH)
 extern int pressure_alt;
+extern unsigned int three_button_mode;
+
+static ssize_t three_button_read_params(struct file *file, char *buf,
+				      size_t nbytes, loff_t *ppos)
+{
+	char outputbuf[32];
+	int count;
+
+	if (*ppos>0) /* Assume reading completed in previous read*/
+		return 0;
+	count = sprintf(outputbuf, "%d\n", (unsigned int)three_button_mode);
+	count++;
+	*ppos += count;
+	if (count>nbytes)	/* Assume output can be read at one time */
+		return -EINVAL;
+	if (copy_to_user(buf, outputbuf, count+1))
+		return -EFAULT;
+	return count;
+}
+
+static ssize_t three_button_write_params(struct file *file, const char *buf,
+				       size_t nbytes, loff_t *ppos)
+{
+	unsigned int param=0;
+
+	sscanf(buf,"%d",&param);
+	if (three_button_mode != param) {
+		three_button_mode = param;
+		printk("three_button = %d\n", three_button_mode);
+	}
+	return nbytes;
+}
+
+static struct file_operations proc_three_button_operations = {
+  read:   three_button_read_params,
+  write:  three_button_write_params,
+};
 #endif
 
 //extern unsigned short touch_panel_intr;
@@ -1020,28 +1100,31 @@
 #elif defined(CONFIG_ARCH_PXA_CORGI)
 		if( pos_dt.xd && pos_dt.yd && Pressure ) {
 #if defined(CONFIG_SL_3BUTTON_PATCH)
-			switch (pressure_alt) {
-			case 0x00:
-				tc.pressure = 500;
-				break;
-			case 0x01:
-				tc.pressure = 1000;
-				break;
-			case 0x02:
-				tc.pressure = 2000;
-				break;
-			default:
-				tc.pressure = 500;
-				break;
-			}
+			if (three_button_mode) {
+				switch (pressure_alt) {
+				case 0x00:
+					tc.pressure = 500;
+					break;
+				case 0x01:
+					tc.pressure = 1000;
+					break;
+				case 0x02:
+					tc.pressure = 2000;
+					break;
+				default:
+					tc.pressure = 500;
+					break;
+				}
 
 		/*	printk("pressure = %d \n",tc.pressure); */
-#else
-			if (tspressure_mode)
+		    } else
+#if defined(CONFIG_SL_TS_PRESSURE)
+			if (tspressure_mode) 
 				tc.pressure = Pressure;
-			else
-				tc.pressure = 500;
+			else 
 #endif
+#endif
+				tc.pressure = 500;
 
 #else
 		if( pos_dt.xd && pos_dt.yd ){
@@ -1097,11 +1180,34 @@
 
 #if defined(CONFIG_SL_TS_PRESSURE)
 	struct proc_dir_entry *tspressure_proc;
+#endif
+
+#if defined(CONFIG_SL_3BUTTON_PATCH)
+	struct proc_dir_entry *three_button_proc;
+#endif
+
+#if defined(CONFIG_SL7X0_POWER_KEY_OFF)
+	struct proc_dir_entry *power_key_off_proc;
+#endif
+
+#if defined(CONFIG_SL_TS_PRESSURE)
 	tspressure_proc = create_proc_entry("tspressure", 0, NULL);
 	if (tspressure_proc)
 		tspressure_proc->proc_fops = &proc_tspressure_operations;
 #endif
 	
+#if defined(CONFIG_SL_3BUTTON_PATCH)
+	three_button_proc = create_proc_entry("three_button", 0, NULL);
+	if (three_button_proc)
+		three_button_proc->proc_fops = &proc_three_button_operations;
+#endif
+	
+#if defined(CONFIG_SL7X0_POWER_KEY_OFF)
+	power_key_off_proc = create_proc_entry("power_key_off", 0, NULL);
+	if (power_key_off_proc)
+		power_key_off_proc->proc_fops = &proc_power_key_off_operations;
+#endif
+	
 #if defined(CONFIG_ARCH_PXA_POODLE) || defined(CONFIG_ARCH_PXA_CORGI)
 	pxa_ssp_init();
 #else
diff -Nur c860_040114/linux/drivers/char/keyboard.c c860_040124/linux/drivers/char/keyboard.c
--- c860_040114/linux/drivers/char/keyboard.c	2004-11-08 18:34:35.000000000 +0900
+++ c860_040124/linux/drivers/char/keyboard.c	2004-11-08 18:34:58.000000000 +0900
@@ -117,7 +117,14 @@
 static struct tty_struct **ttytab;
 static struct kbd_struct * kbd = kbd_table;
 static struct tty_struct * tty;
+
+#if defined(CONFIG_SL7X0_POWER_KEY_OFF)
+unsigned int power_key_off_mode;
+#endif
+#if defined(CONFIG_SL_3BUTTON_PATCH)
+unsigned int three_button_mode;
 int pressure_alt;
+#endif
 
 static void kbd_processkeycode(unsigned char scancode, char up_flag, int autorepeat);
 void compute_shiftstate(void);
@@ -230,7 +237,7 @@
 #if defined(CONFIG_SL7X0_POWER_KEY_OFF)
 	/* printk("scancode = %x down = %x \n",scancode,down); */
 	/* SL-C700 side power 0x6d  */ 
-	if ( ( scancode == 0x6d ) && ( down == 0x01 ) ){ 
+	if ( power_key_off_mode && ( scancode == 0x6d ) && ( down == 0x01 ) ){ 
 
 		printk("power button\n");
 		slc7x0_key_suspend();
@@ -240,29 +247,28 @@
 	} else
 #endif
 #if defined(CONFIG_SL_3BUTTON_PATCH)
-               if ( ( scancode == 0x59 ) && ( down == 0x01 ) ){
+               if ( three_button_mode && ( scancode == 0x59 ) && ( down == 0x01 ) ){
 
 		pressure_alt=0x01;
 		handle_scancode_main ( scancode, down );
 
 	/* SL-C700 Calender up 0xd8  */ 
-	} else if ( ( scancode == 0xd9 ) && ( down == 0x00 ) ){
+	} else if ( three_button_mode && ( scancode == 0xd9 ) && ( down == 0x00 ) ){
 
 		pressure_alt=0x00;
 		handle_scancode_main ( scancode, down );
 
 	/* SL-C700 Address down 0x59  */ 
-	} else if ( ( scancode == 0x28 ) && ( down == 0x01 ) ){
+	} else if ( three_button_mode && ( scancode == 0x28 ) && ( down == 0x01 ) ){
 
 		pressure_alt=0x02;
 		handle_scancode_main ( scancode, down );
 
 	/* SL-C700 Address up 0xd9  */ 
-	} else if ( ( scancode == 0xa8 ) && ( down == 0x00 ) ){
+	} else if ( three_button_mode && ( scancode == 0xa8 ) && ( down == 0x00 ) ){
 
 		pressure_alt=0x00;
 		handle_scancode_main ( scancode, down );
-
 	} else
 #endif
 #if defined(CONFIG_SL7X0_POWER_KEY_OFF) || defined(CONFIG_SL_3BUTTON_PATCH)
